import { SolanaSignInData } from '@phantom/browser-sdk/solana';
import { Transaction } from '@solana/kit';

type UseConnectProps = {
    autoConnect?: boolean;
};
declare function useConnect({ autoConnect }?: UseConnectProps): {
    connect: () => Promise<string | undefined>;
};

declare function useDisconnect(): {
    disconnect: () => Promise<void>;
};

interface UseSignInResult {
    signIn: (signInData: SolanaSignInData) => Promise<{
        address: string;
        signature: Uint8Array;
        signedMessage: Uint8Array;
    }>;
}
declare function useSignIn(): UseSignInResult;

interface UseSignAndSendTransactionResult {
    signAndSendTransaction: (transaction: Transaction) => Promise<{
        signature: string;
        publicKey?: string;
    }>;
}
declare function useSignAndSendTransaction(): UseSignAndSendTransactionResult;

interface UseSignMessageResult {
    signMessage: (message: Uint8Array, display?: "utf8" | "hex") => Promise<{
        signature: Uint8Array;
        address: string;
    }>;
}
declare function useSignMessage(): UseSignMessageResult;

/**
 * React hook that provides the current account connection status and public key.
 * Automatically updates when the account connects, disconnects, or changes.
 *
 * @returns Object containing status ('connected' | 'disconnected') and address (string | null)
 */
declare function useAccount(): string | undefined;

type UseAccountEffectParameters = {
    onConnect?(data: {
        publicKey: string;
    }): void;
    onDisconnect?(): void;
    onAccountChanged?(data: {
        publicKey: string;
    }): void;
};
/**
 * Hook for listening to account lifecycle events.
 * Provides callbacks for connect, disconnect, and account change events.
 */
declare function useAccountEffect(parameters?: UseAccountEffectParameters): void;

export { useAccount, useAccountEffect, useConnect, useDisconnect, useSignAndSendTransaction, useSignIn, useSignMessage };
