"use strict";
var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/solana/index.ts
var solana_exports = {};
__export(solana_exports, {
  useAccount: () => useAccount,
  useAccountEffect: () => useAccountEffect,
  useConnect: () => useConnect,
  useDisconnect: () => useDisconnect,
  useSignAndSendTransaction: () => useSignAndSendTransaction,
  useSignIn: () => useSignIn,
  useSignMessage: () => useSignMessage
});
module.exports = __toCommonJS(solana_exports);
var import_solana = require("@phantom/browser-sdk/solana");

// src/solana/useConnect.ts
var React2 = __toESM(require("react"));

// src/PhantomContext.tsx
var import_browser_sdk = require("@phantom/browser-sdk");
var React = __toESM(require("react"));
var import_jsx_runtime = require("react/jsx-runtime");
var PhantomContext = React.createContext({ phantom: void 0, isReady: false });
function usePhantom() {
  const context = React.useContext(PhantomContext);
  if (!context) {
    throw new Error("usePhantom must be used within a PhantomProvider");
  }
  return context;
}

// src/solana/useConnect.ts
function useConnect({ autoConnect = false } = {}) {
  const { phantom } = usePhantom();
  const connect = React2.useCallback(async () => {
    if (!phantom?.solana) {
      throw new Error("Phantom solana plugin not found.");
    }
    return await phantom.solana.connect();
  }, [phantom]);
  React2.useEffect(() => {
    if (autoConnect && phantom?.solana) {
      connect();
    }
  }, [autoConnect, connect, phantom?.solana]);
  return { connect };
}

// src/solana/useDisconnect.ts
var React3 = __toESM(require("react"));
function useDisconnect() {
  const { phantom } = usePhantom();
  const disconnect = React3.useCallback(async () => {
    if (!phantom?.solana) {
      throw new Error("Phantom solana disconnect method not found.");
    }
    return await phantom.solana.disconnect();
  }, [phantom]);
  return { disconnect };
}

// src/solana/useSignIn.ts
var import_react = require("react");
function useSignIn() {
  const { phantom } = usePhantom();
  const signIn = (0, import_react.useCallback)(
    async (signInData) => {
      if (!phantom?.solana) {
        throw new Error("Phantom Solana provider not available.");
      }
      const result = await phantom.solana.signIn(signInData);
      return result;
    },
    [phantom]
  );
  return { signIn };
}

// src/solana/useSignAndSendTransaction.ts
var import_react2 = require("react");
function useSignAndSendTransaction() {
  const { phantom } = usePhantom();
  const signAndSendTransaction = (0, import_react2.useCallback)(
    async (transaction) => {
      if (!phantom?.solana) {
        throw new Error("Phantom Solana provider not available.");
      }
      const result = await phantom.solana.signAndSendTransaction(transaction);
      return result;
    },
    [phantom]
  );
  return { signAndSendTransaction };
}

// src/solana/useSignMessage.ts
var import_react3 = require("react");
function useSignMessage() {
  const { phantom } = usePhantom();
  const signMessage = (0, import_react3.useCallback)(
    async (message, display) => {
      if (!phantom?.solana) {
        throw new Error("Phantom Solana provider not available.");
      }
      const result = await phantom.solana.signMessage(message, display);
      return result;
    },
    [phantom]
  );
  return { signMessage };
}

// src/solana/useAccount.ts
var React4 = __toESM(require("react"));

// src/solana/assertions.ts
function assertSolanaConfigured(phantom) {
  if (!phantom?.solana) {
    throw new Error(
      "Phantom solana chain plugin not found. Please ensure the solana chain plugin is installed and configured properly."
    );
  }
}

// src/solana/useAccount.ts
function useAccount() {
  const { phantom, isReady } = usePhantom();
  const [account, setAccount] = React4.useState(void 0);
  React4.useEffect(() => {
    if (!isReady)
      return;
    assertSolanaConfigured(phantom);
    const updateAccount = async () => {
      setAccount(await phantom.solana.getAccount());
    };
    updateAccount();
    phantom.solana.addEventListener("connect", updateAccount);
    phantom.solana.addEventListener("disconnect", updateAccount);
    phantom.solana.addEventListener("accountChanged", updateAccount);
    return () => {
      phantom.solana.removeEventListener("connect", updateAccount);
      phantom.solana.removeEventListener("disconnect", updateAccount);
      phantom.solana.removeEventListener("accountChanged", updateAccount);
    };
  }, [phantom, isReady]);
  return account;
}

// src/solana/useAccountEffect.ts
var React5 = __toESM(require("react"));
function useAccountEffect(parameters = {}) {
  const { onConnect, onDisconnect, onAccountChanged } = parameters;
  const { phantom, isReady } = usePhantom();
  React5.useEffect(() => {
    if (!isReady)
      return;
    assertSolanaConfigured(phantom);
    const handleConnect = (publicKey) => {
      onConnect?.({
        publicKey
      });
    };
    const handleDisconnect = () => {
      onDisconnect?.();
    };
    const handleAccountChanged = (publicKey) => {
      onAccountChanged?.({
        publicKey
      });
    };
    if (onConnect) {
      phantom.solana.addEventListener("connect", handleConnect);
    }
    if (onDisconnect) {
      phantom.solana.addEventListener("disconnect", handleDisconnect);
    }
    if (onAccountChanged) {
      phantom.solana.addEventListener("accountChanged", handleAccountChanged);
    }
    return () => {
      if (onConnect) {
        phantom.solana.removeEventListener("connect", handleConnect);
      }
      if (onDisconnect) {
        phantom.solana.removeEventListener("disconnect", handleDisconnect);
      }
      if (onAccountChanged) {
        phantom.solana.removeEventListener("accountChanged", handleAccountChanged);
      }
    };
  }, [isReady, phantom, onConnect, onDisconnect, onAccountChanged]);
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  useAccount,
  useAccountEffect,
  useConnect,
  useDisconnect,
  useSignAndSendTransaction,
  useSignIn,
  useSignMessage
});
